@@ -1,3 +1,5 @@
+import { INVOICE_STATUSES } from '@tamanu/constants';
+import { getInvoiceSummary } from '@tamanu/shared/utils/invoice';
 import express from 'express';
 import asyncHandler from 'express-async-handler';
 
@@ -52,3 +54,36 @@ patientInvoiceRoutes.get(
     });
   }),
 );
+
+patientInvoiceRoutes.get(
+  '/:id/invoices/totalOutstandingBalance',
+  asyncHandler(async (req, res) => {
+    req.checkPermission('list', 'Invoice');
+
+    const { models, params } = req;
+    const patientId = params.id;
+
+    const invoices = await models.Invoice.findAll({
+      where: {
+        status: INVOICE_STATUSES.FINALISED,
+      },
+      include: [
+        ...models.Invoice.getFullReferenceAssociations(),
+        {
+          model: models.Encounter,
+          as: 'encounter',
+          where: { patientId },
+        },
+      ],
+    });
+
+    const balance = invoices.reduce(
+      (acc, invoice) => acc + getInvoiceSummary(invoice).patientPaymentRemainingBalance,
+      0,
+    );
+
+    res.send({
+      result: balance,
+    });
+  }),
+);
