@@ -42,8 +42,8 @@ export const CovidPatientDetailsSection = ({
             const value =
               accessor?.(patient, { getLocalisation, getTranslation }) ?? (patient[key] || '');
             const label =
-              getTranslation(`general.localisedFields.${key}.label.short`) ||
-              getTranslation(`general.localisedFields.${key}.label`) ||
+              getTranslation(`general.localisedField.${key}.label.short`) ||
+              getTranslation(`general.localisedField.${key}.label`) ||
               defaultLabel;
 
             return (
